/* ANSI-C code produced by gperf version 3.3 */
/* Command-line: gperf --readonly-tables --includes --struct-type --omit-struct-type --lookup-function-name=shumate_vector_expression_type_lookup --hash-function-name=shumate_vector_expression_type_hash --output-file=shumate/shumate-vector-expression-gperf.c ../libshumate/shumate/vector/shumate-vector-expression-type.gperf  */
/* Computed positions: -k'1-2,$' */

#if !((' ' == 32) && ('!' == 33) && ('"' == 34) && ('#' == 35) \
      && ('%' == 37) && ('&' == 38) && ('\'' == 39) && ('(' == 40) \
      && (')' == 41) && ('*' == 42) && ('+' == 43) && (',' == 44) \
      && ('-' == 45) && ('.' == 46) && ('/' == 47) && ('0' == 48) \
      && ('1' == 49) && ('2' == 50) && ('3' == 51) && ('4' == 52) \
      && ('5' == 53) && ('6' == 54) && ('7' == 55) && ('8' == 56) \
      && ('9' == 57) && (':' == 58) && (';' == 59) && ('<' == 60) \
      && ('=' == 61) && ('>' == 62) && ('?' == 63) && ('A' == 65) \
      && ('B' == 66) && ('C' == 67) && ('D' == 68) && ('E' == 69) \
      && ('F' == 70) && ('G' == 71) && ('H' == 72) && ('I' == 73) \
      && ('J' == 74) && ('K' == 75) && ('L' == 76) && ('M' == 77) \
      && ('N' == 78) && ('O' == 79) && ('P' == 80) && ('Q' == 81) \
      && ('R' == 82) && ('S' == 83) && ('T' == 84) && ('U' == 85) \
      && ('V' == 86) && ('W' == 87) && ('X' == 88) && ('Y' == 89) \
      && ('Z' == 90) && ('[' == 91) && ('\\' == 92) && (']' == 93) \
      && ('^' == 94) && ('_' == 95) && ('a' == 97) && ('b' == 98) \
      && ('c' == 99) && ('d' == 100) && ('e' == 101) && ('f' == 102) \
      && ('g' == 103) && ('h' == 104) && ('i' == 105) && ('j' == 106) \
      && ('k' == 107) && ('l' == 108) && ('m' == 109) && ('n' == 110) \
      && ('o' == 111) && ('p' == 112) && ('q' == 113) && ('r' == 114) \
      && ('s' == 115) && ('t' == 116) && ('u' == 117) && ('v' == 118) \
      && ('w' == 119) && ('x' == 120) && ('y' == 121) && ('z' == 122) \
      && ('{' == 123) && ('|' == 124) && ('}' == 125) && ('~' == 126))
/* The character set is not based on ISO-646.  */
#error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gperf@gnu.org>."
#endif

#line 1 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"

#include "vector/shumate-vector-expression-type-private.h"
#define EXACT(c) .expect_exprs = c, .expect_exprs_set = 1
#define GE(c) .expect_ge_exprs = c, .expect_ge_exprs_set = 1
#define LE(c) .expect_le_exprs = c, .expect_le_exprs_set = 1
#include <string.h>

#define TOTAL_KEYWORDS 68
#define MIN_WORD_LENGTH 1
#define MAX_WORD_LENGTH 15
#define MIN_HASH_VALUE 1
#define MAX_HASH_VALUE 116
/* maximum key range = 116, duplicates = 0 */

#ifdef __GNUC__
__inline
#else
#ifdef __cplusplus
inline
#endif
#endif
static unsigned int
shumate_vector_expression_type_hash (register const char *str, register size_t len)
{
  static const unsigned char asso_values[] =
    {
      117, 117, 117, 117, 117, 117, 117, 117, 117, 117,
      117, 117, 117, 117, 117, 117, 117, 117, 117, 117,
      117, 117, 117, 117, 117, 117, 117, 117, 117, 117,
      117, 117, 117,  45, 117, 117, 117,  55, 117, 117,
      117, 117,  50,  35, 117,  20, 117,  10,   5, 117,
       80, 117, 117, 117, 117, 117, 117, 117, 117, 117,
       40,   0,  30, 117, 117, 117, 117, 117, 117, 117,
      117, 117, 117, 117, 117, 117, 117, 117, 117, 117,
      117, 117, 117, 117, 117, 117, 117, 117, 117, 117,
      117, 117, 117, 117,   5, 117, 117,  10,  75,  10,
       45,   0,  45,  45,  35,  20, 117, 117,   5,  60,
        0,   0,  25,  30,  25,  15,   0,   5,  60, 117,
       20,  65,   0, 117, 117, 117, 117, 117, 117, 117,
      117, 117, 117, 117, 117, 117, 117, 117, 117, 117,
      117, 117, 117, 117, 117, 117, 117, 117, 117, 117,
      117, 117, 117, 117, 117, 117, 117, 117, 117, 117,
      117, 117, 117, 117, 117, 117, 117, 117, 117, 117,
      117, 117, 117, 117, 117, 117, 117, 117, 117, 117,
      117, 117, 117, 117, 117, 117, 117, 117, 117, 117,
      117, 117, 117, 117, 117, 117, 117, 117, 117, 117,
      117, 117, 117, 117, 117, 117, 117, 117, 117, 117,
      117, 117, 117, 117, 117, 117, 117, 117, 117, 117,
      117, 117, 117, 117, 117, 117, 117, 117, 117, 117,
      117, 117, 117, 117, 117, 117, 117, 117, 117, 117,
      117, 117, 117, 117, 117, 117, 117, 117, 117, 117,
      117, 117, 117, 117, 117, 117
    };
  register unsigned int hval = len;

  switch (hval)
    {
      default:
        hval += asso_values[(unsigned char)str[1]];
#if (defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang__ && __clang_major__ + (__clang_minor__ >= 9) > 3))) || (defined __STDC_VERSION__ && __STDC_VERSION__ >= 202000L && ((defined __GNUC__ && __GNUC__ >= 10) || (defined __clang__ && __clang_major__ >= 9)))
      [[fallthrough]];
#elif (defined __GNUC__ && __GNUC__ >= 7) || (defined __clang__ && __clang_major__ >= 10)
      __attribute__ ((__fallthrough__));
#endif
      /*FALLTHROUGH*/
      case 1:
        hval += asso_values[(unsigned char)str[0]];
        break;
    }
  return hval + asso_values[(unsigned char)str[len - 1]];
}

const struct _ExprInfo *
shumate_vector_expression_type_lookup (register const char *str, register size_t len)
{
#if (defined __GNUC__ && __GNUC__ + (__GNUC_MINOR__ >= 6) > 4) || (defined __clang__ && __clang_major__ >= 3)
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif
  static const struct _ExprInfo wordlist[] =
    {
      {""},
#line 79 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"e", EXPR_E, EXACT(0)},
#line 50 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"==", EXPR_EQ, GE(2), LE(3), .lookup_first_arg = TRUE},
      {""},
#line 55 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"none", EXPR_NONE},
      {""}, {""},
#line 81 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"ln", EXPR_LN, EXACT(1)},
#line 61 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"let", EXPR_LET},
      {""},
#line 29 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"to-boolean", EXPR_TO_BOOLEAN, EXACT(1)},
#line 71 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"^", EXPR_POW, EXACT(2)},
#line 37 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"at", EXPR_AT, EXACT(2)},
#line 91 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"tan", EXPR_TAN, EXACT(1)},
#line 76 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"atan", EXPR_ATAN, EXACT(1)},
#line 83 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"log10", EXPR_LOG10, EXACT(1)},
#line 63 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"concat", EXPR_CONCAT},
      {""},
#line 57 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"coalesce", EXPR_COALESCE},
#line 77 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"ceil", EXPR_CEIL, EXACT(1)},
      {""},
#line 69 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"/", EXPR_DIV, EXACT(2)},
#line 41 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"in", EXPR_IN, GE(1), .lookup_first_arg = TRUE},
#line 53 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"all", EXPR_ALL},
#line 56 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"case", EXPR_CASE},
#line 45 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"slice", EXPR_SLICE, GE(2), LE(3)},
      {""}, {""},
#line 78 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"cos", EXPR_COS, EXACT(1)},
#line 75 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"asin", EXPR_ASIN, EXACT(1)},
      {""},
#line 59 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"interpolate", EXPR_INTERPOLATE},
#line 52 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {">=", EXPR_GE, GE(2), LE(3), .lookup_first_arg = TRUE},
#line 30 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"to-color", EXPR_TO_COLOR, GE(1)},
#line 31 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"to-number", EXPR_TO_NUMBER, GE(1)},
      {""},
#line 66 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"upcase", EXPR_UPCASE, EXACT(1)},
#line 28 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"literal", EXPR_TYPE_LITERAL, EXACT(1)},
#line 89 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"sin", EXPR_SIN, EXACT(1)},
#line 74 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"acos", EXPR_ACOS, EXACT(1)},
#line 65 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"resolved-locale", EXPR_RESOLVED_LOCALE},
#line 67 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"-", EXPR_SUB, GE(1), LE(2)},
#line 49 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"<=", EXPR_LE, GE(2), LE(3), .lookup_first_arg = TRUE},
#line 25 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"collator", EXPR_COLLATOR},
#line 60 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"step", EXPR_STEP},
      {""},
#line 44 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"length", EXPR_LENGTH, EXACT(1)},
#line 47 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"!=", EXPR_NE, GE(2), LE(3), .lookup_first_arg = TRUE},
#line 38 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"get", EXPR_GET, EXACT(1)},
#line 90 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"sqrt", EXPR_SQRT, EXACT(1)},
      {""},
#line 26 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"format", EXPR_FORMAT},
      {""},
#line 64 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"downcase", EXPR_DOWNCASE, EXACT(1)},
#line 32 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"to-string", EXPR_TO_STRING, EXACT(1)},
      {""}, {""}, {""},
#line 34 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"geometry-type", EXPR_GEOMETRY_TYPE, EXACT(0)},
      {""}, {""},
#line 51 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {">", EXPR_GT, GE(2), LE(3), .lookup_first_arg = TRUE},
#line 36 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"global-state", EXPR_GLOBAL_STATE, EXACT(1)},
#line 39 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"has", EXPR_HAS, EXACT(1)},
#line 92 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"zoom", EXPR_ZOOM},
      {""}, {""},
#line 87 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"pi", EXPR_PI, EXACT(0)},
#line 42 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"!in", EXPR_NOT_IN, GE(1), .lookup_first_arg = TRUE},
      {""}, {""},
#line 72 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"+", EXPR_ADD, GE(1)},
      {""},
#line 43 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"index-of", EXPR_INDEX_OF, GE(2), LE(3)},
      {""},
#line 88 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"round", EXPR_ROUND, EXACT(1)},
      {""}, {""},
#line 54 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"any", EXPR_ANY},
      {""},
#line 80 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"floor", EXPR_FLOOR, EXACT(1)},
#line 48 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"<", EXPR_LT, GE(2), LE(3), .lookup_first_arg = TRUE},
      {""},
#line 86 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"min", EXPR_MIN, GE(1)},
      {""},
#line 27 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"image", EXPR_IMAGE, EXACT(1)},
      {""}, {""},
#line 82 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"ln2", EXPR_LN2, EXACT(0)},
#line 84 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"log2", EXPR_LOG2, EXACT(1)},
      {""},
#line 46 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"!", EXPR_NOT, EXACT(1)},
      {""},
#line 85 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"max", EXPR_MAX, GE(1)},
      {""}, {""}, {""}, {""},
#line 62 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"var", EXPR_VAR},
#line 40 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"!has", EXPR_NOT_HAS, EXACT(1)},
      {""},
#line 68 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"*", EXPR_MUL, GE(1)},
      {""},
#line 73 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"abs", EXPR_ABS, EXACT(1)},
      {""}, {""}, {""}, {""}, {""}, {""},
#line 58 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"match", EXPR_MATCH, GE(2)},
#line 70 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"%", EXPR_REM, EXACT(2)},
#line 35 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"id", EXPR_ID, EXACT(0)},
      {""}, {""}, {""},
#line 33 "../libshumate/shumate/vector/shumate-vector-expression-type.gperf"
      {"typeof", EXPR_TYPEOF, EXACT(1)}
    };
#if (defined __GNUC__ && __GNUC__ + (__GNUC_MINOR__ >= 6) > 4) || (defined __clang__ && __clang_major__ >= 3)
#pragma GCC diagnostic pop
#endif

  if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
    {
      register unsigned int key = shumate_vector_expression_type_hash (str, len);

      if (key <= MAX_HASH_VALUE)
        {
          register const char *s = wordlist[key].name;

          if (*str == *s && !strcmp (str + 1, s + 1))
            return &wordlist[key];
        }
    }
  return (struct _ExprInfo *) 0;
}
